@@ -1,5 +1,6 @@
 import logging
 
+from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.decorators import user_passes_test
@@ -10,12 +11,12 @@ from django.db.models import Count
 from django.http import Http404
 from django.shortcuts import render, redirect, get_object_or_404
 from django.utils.translation import ugettext_lazy as _
-from .managers import GroupManager
-from .models import GroupRequest, RequestLog
 
 from allianceauth.notifications import notify
 
-from django.conf import settings
+from .managers import GroupManager
+from .models import GroupRequest, RequestLog
+
 
 logger = logging.getLogger(__name__)
 
@@ -33,7 +34,8 @@ def group_management(request):
         group_requests = base_group_query.all()
     else:
         # Group specific leader
-        group_requests = base_group_query.filter(group__authgroup__group_leaders__in=[request.user])
+        users__groups = GroupManager.get_group_leaders_groups(request.user)
+        group_requests = base_group_query.filter(group__in=users__groups)
 
     for grouprequest in group_requests:
         if grouprequest.leave_request:
@@ -234,7 +236,7 @@ def group_reject_request(request, group_request_id):
         raise p
     except:
         messages.error(request, _('An unhandled error occurred while processing the application from %(mainchar)s to %(group)s.') % {"mainchar": group_request.main_char, "group": group_request.group})
-        logger.exception("Unhandled exception occured while user %s attempting to reject group request id %s" % (
+        logger.exception("Unhandled exception occurred while user %s attempting to reject group request id %s" % (
             request.user, group_request_id))
         pass
 
@@ -268,9 +270,9 @@ def group_leave_accept_request(request, group_request_id):
                        (request.user, group_request_id))
         raise p
     except:
-        messages.error(request, _('An unhandled error occured while processing the application from %(mainchar)s to leave %(group)s.') % {
+        messages.error(request, _('An unhandled error occurred while processing the application from %(mainchar)s to leave %(group)s.') % {
             "mainchar": group_request.main_char, "group": group_request.group})
-        logger.exception("Unhandled exception occured while user %s attempting to accept group leave request id %s" % (
+        logger.exception("Unhandled exception occurred while user %s attempting to accept group leave request id %s" % (
             request.user, group_request_id))
         pass
 
@@ -302,9 +304,9 @@ def group_leave_reject_request(request, group_request_id):
                        (request.user, group_request_id))
         raise p
     except:
-        messages.error(request, _('An unhandled error occured while processing the application from %(mainchar)s to leave %(group)s.') % {
+        messages.error(request, _('An unhandled error occurred while processing the application from %(mainchar)s to leave %(group)s.') % {
             "mainchar": group_request.main_char, "group": group_request.group})
-        logger.exception("Unhandled exception occured while user %s attempting to reject group leave request id %s" % (
+        logger.exception("Unhandled exception occurred while user %s attempting to reject group leave request id %s" % (
             request.user, group_request_id))
         pass
 
@@ -314,24 +316,23 @@ def group_leave_reject_request(request, group_request_id):
 @login_required
 def groups_view(request):
     logger.debug("groups_view called by user %s" % request.user)
+    
+    groups_qs = GroupManager.get_joinable_groups_for_user(
+        request.user, include_hidden=False
+    )
+    groups_qs = groups_qs.order_by('name')
     groups = []
+    for group in groups_qs:        
+        group_request = GroupRequest.objects\
+            .filter(user=request.user)\
+            .filter(group=group)
+        groups.append({
+            'group': group, 
+            'request': group_request[0] if group_request else None
+        })
 
-    group_query = GroupManager.get_joinable_groups(request.user.profile.state)
-
-    if not request.user.has_perm('groupmanagement.request_groups'):
-        # Filter down to public groups only for non-members
-        group_query = group_query.filter(authgroup__public=True)
-        logger.debug("Not a member, only public groups will be available")
-
-    for group in group_query:
-        # Exclude hidden
-        if not group.authgroup.hidden:
-            group_request = GroupRequest.objects.filter(user=request.user).filter(group=group)
-
-            groups.append({'group': group, 'request': group_request[0] if group_request else None})
-
-    render_items = {'groups': groups}
-    return render(request, 'groupmanagement/groups.html', context=render_items)
+    context = {'groups': groups}
+    return render(request, 'groupmanagement/groups.html', context=context)
 
 
 @login_required
@@ -348,13 +349,13 @@ def group_request_add(request, group_id):
         # User is already a member of this group.
         logger.warning("User %s attempted to join group id %s but they are already a member." %
                        (request.user, group_id))
-        messages.warning(request, "You are already a member of that group.")
+        messages.warning(request, _("You are already a member of that group."))
         return redirect('groupmanagement:groups')
     if not request.user.has_perm('groupmanagement.request_groups') and not group.authgroup.public:
         # Does not have the required permission, trying to join a non-public group
         logger.warning("User %s attempted to join group id %s but it is not a public group" %
                        (request.user, group_id))
-        messages.warning(request, "You cannot join that group")
+        messages.warning(request, _("You cannot join that group"))
         return redirect('groupmanagement:groups')
     if group.authgroup.open:
         logger.info("%s joining %s as is an open group" % (request.user, group))
@@ -363,7 +364,7 @@ def group_request_add(request, group_id):
     req = GroupRequest.objects.filter(user=request.user, group=group)
     if len(req) > 0:
         logger.info("%s attempted to join %s but already has an open application" % (request.user, group))
-        messages.warning(request, "You already have a pending application for that group.")
+        messages.warning(request, _("You already have a pending application for that group."))
         return redirect("groupmanagement:groups")
     grouprequest = GroupRequest()
     grouprequest.status = _('Pending')
@@ -397,7 +398,7 @@ def group_request_leave(request, group_id):
     req = GroupRequest.objects.filter(user=request.user, group=group)
     if len(req) > 0:
         logger.info("%s attempted to leave %s but already has an pending leave request." % (request.user, group))
-        messages.warning(request, "You already have a pending leave request for that group.")
+        messages.warning(request, _("You already have a pending leave request for that group."))
         return redirect("groupmanagement:groups")
     if getattr(settings, 'AUTO_LEAVE', False):
         logger.info("%s leaving joinable group %s due to auto_leave" % (request.user, group))
